@@ -1,10 +1,13 @@
 """Module for importing data recorded by NilsPod sensors."""
 import datetime
 from pathlib import Path
-from typing import Optional, Sequence, Union, Tuple, Dict, Literal
+from typing import Optional, Sequence, Union, Tuple, Dict
 
 import re
 import warnings
+
+from typing_extensions import Literal
+
 import numpy as np
 import pandas as pd
 
